==> haskell-hls-fourmolu-plugin-2.1.0.0-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-fourmolu-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-fourmolu-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-fourmolu-plugin-2.1.0.0-FYeZJXaigGt4wLpADSifN3
key:                  hls-fourmolu-plugin-2.1.0.0-FYeZJXaigGt4wLpADSifN3
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server
synopsis:             Integration with the Fourmolu code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  c385d001d2f295e2a3dd9352af2c7fea
exposed:              True
exposed-modules:      Ide.Plugin.Fourmolu Ide.Plugin.Fourmolu.Shim
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-fourmolu-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-fourmolu-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-fourmolu-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-fourmolu-plugin
hs-libraries:         HShls-fourmolu-plugin-2.1.0.0-FYeZJXaigGt4wLpADSifN3
depends:
    base-4.17.2.1 filepath-1.4.2.2
    fourmolu-0.11.0.0-9UQrqAKk6wP7GPgLbkWhHQ ghc-9.4.8
    ghc-boot-th-9.4.8 ghcide-2.1.0.0-12sPff9pKn4Im0ClDrHigm
    hls-plugin-api-2.1.0.0-2uAvPpzQyqQEBCnm58a3ku
    lens-5.3-HdczP0no6IA6OsB2lfUnLL lsp-2.1.0.0-gI4sjr8ace9num3GDSHxI
    mtl-2.2.2 process-extras-0.7.4-IbEPNSCbMcR7UQlkYznWIs text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-fourmolu-plugin/html/hls-fourmolu-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-fourmolu-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-fourmolu-plugin-2.1.0.0-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-fourmolu-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-fourmolu-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-fourmolu-plugin-2.1.0.0-DD6F3xpL4pH3XuOyKiUy8h
key:                  hls-fourmolu-plugin-2.1.0.0-DD6F3xpL4pH3XuOyKiUy8h
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server
synopsis:             Integration with the Fourmolu code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  4bce33918501805a8bf580dd56d849e3
exposed:              True
exposed-modules:      Ide.Plugin.Fourmolu Ide.Plugin.Fourmolu.Shim
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-fourmolu-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-fourmolu-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-fourmolu-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-fourmolu-plugin
hs-libraries:         HShls-fourmolu-plugin-2.1.0.0-DD6F3xpL4pH3XuOyKiUy8h
depends:
    base-4.17.2.1 filepath-1.4.2.2
    fourmolu-0.11.0.0-CPFdrlzw76CD5PkOvsC8IK ghc-9.4.8
    ghc-boot-th-9.4.8 ghcide-2.1.0.0-2X63pA79pDQJ25RsfosNdg
    hls-plugin-api-2.1.0.0-A9q6fYJiV9n788ynWNmuML
    lens-5.3-pl18ecYYzn8sW5PtrryAE lsp-2.1.0.0-DnlBzEwRSs1GzYbMC2TL46
    mtl-2.2.2 process-extras-0.7.4-AomsG3YRQaBJpAEikKviI5 text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-fourmolu-plugin/html/hls-fourmolu-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-fourmolu-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
